<template>
  <ProDialog title="理赔详情" v-model="innerVisible" width="1200px" destroy-on-close>
    <ProDialogTableWrapper :height="400">
      <ProTableV2
        :table-data="proTableProps.tableData"
        :columns="column"
        :operation-btns="operationBtns"
      >
        <template #changeType="{ row }"> {{ BatchChangeTypeEnumText[row.changeType] }}</template>
      </ProTableV2>
    </ProDialogTableWrapper>
  </ProDialog>
</template>

<script setup lang="ts">
import {
  ProDialog,
  ProTableV2,
  ProDialogTableWrapper,
  useTable,
  defineOperationBtns,
} from '@bole-core/components';
import { OrderInputType } from '@bole-core/core';
import { paginateList } from '@/utils';
import { BatchChangeTypeEnumText } from '@/constants';

defineOptions({
  name: 'InsureClaimDetailDialog',
});

type Props = {
  modelValue: boolean;
  form?: {
    id: string;
    staffList: API.InsureBatchBillDetailDto[];
  };
};

const props = withDefaults(defineProps<Props>(), {
  modelValue: false,
});

const emit = defineEmits<{
  (e: 'update:modelValue', value: boolean): void;
  (e: 'onCancel'): void;
}>();

const column: API.CustomModuleColumnDto[] = [
  {
    id: '1',
    enCode: 'name',
    name: '姓名',
  },
  {
    id: '2',
    enCode: 'idNumber',
    name: '身份证号',
  },
  {
    id: '3',
    enCode: 'idNumber',
    name: '报案时间',
  },
  {
    id: '4',
    enCode: 'idNumber',
    name: '联系电话',
  },
  {
    id: '5',
    enCode: 'idNumber',
    name: '事故类型',
  },
  {
    id: '6',
    enCode: 'idNumber',
    name: '理赔结果',
  },
];

const operationBtns = defineOperationBtns([
  {
    data: {
      enCode: 'detailBtn',
      name: '查看',
    },
    emits: {
      onClick: (role) => handleInsureClaimDetail(role),
    },
  },
]);

const router = useRouter();

const innerVisible = computed({
  get() {
    return props.modelValue;
  },
  set(val) {
    emit('update:modelValue', val);
  },
});

watch(
  () => props.modelValue,
  (val) => {
    if (val) {
      getList();
    }
  },
  {
    immediate: true,
  }
);

const {
  getDataSource: getList,
  proTableProps,
  paginationState,
  extraParamState,
  reset,
} = useTable(
  async ({ pageIndex, pageSize }, extraParamState) => {
    try {
      return Promise.resolve({
        pageModel: {
          rows: pageSize,
          page: pageIndex,
          totalCount: props.form.staffList.length,
        },
        data: paginateList(props.form.staffList, pageIndex, pageSize),
      });
    } catch (error) {}
  },
  {
    defaultExtraParams: {
      keyWord: '',
      orderInput: [{ property: 'id', order: OrderInputType.Asc }],
    },
  }
);

function handleInsureClaimDetail(row: API.GetInsuranceStaffPageTemplate) {
  router.push({
    name: 'InsuranceClaimDetail',
    params: {
      id: row.id,
    },
    query: {
      fromRoute: 'InsuranceOrderDetail',
    },
  });
}
</script>

<style lang="scss" scoped>
@use '@/style/common.scss' as *;
</style>
